pub struct IfStatement {
pub decorators: Vec<Decorator>,
pub is_declare: bool,
pub test: Expression,
pub consequent: Box<Statement>,
pub alternate: Option<Box<Statement>>,
pub span: Range<usize>,
}Expand description
Represents an if statement.
Fields
decorators: Vec<Decorator>Decorators associated with the statement.
is_declare: boolWhether the statement is declared with declare.
test: ExpressionThe condition being tested.
consequent: Box<Statement>The statement to execute if the condition is true.
alternate: Option<Box<Statement>>The statement to execute if the condition is false.
span: Range<usize>Source span of the statement.